@@ -39,43 +39,6 @@
 
 #define GRADIENT_BAND_SIZE 4
 
-/**
- * eel_fill_rectangle:
- * @drawable: Target to draw into.
- * @gc: Graphics context (mainly for clip).
- * @rectangle: Rectangle to fill.
- *
- * Fill the rectangle with the foreground color.
- * Convenient when you have a GdkRectangle structure.
- */
-void
-eel_fill_rectangle (GdkDrawable *drawable,
-		    GdkGC *gc,
-		    const GdkRectangle *rectangle)
-{
-	gdk_draw_rectangle (drawable, gc, TRUE,
-			    rectangle->x, rectangle->y,
-			    rectangle->width, rectangle->height);
-}
-
-/**
- * eel_rectangle_contains:
- * @rectangle: Rectangle possibly containing a point.
- * @x: X coordinate of a point.
- * @y: Y coordinate of a point.
- *
- * Retun TRUE if point is contained inside a rectangle
- */
-gboolean
-eel_rectangle_contains (const GdkRectangle *rectangle, 
-			     int x, 
-			     int y)
-{
-	g_return_val_if_fail (rectangle != NULL, FALSE);
-	return rectangle->x <= x && rectangle->x + rectangle->width >= x
-		&& rectangle->y <= y && rectangle->y + rectangle->height >= y;
-}
-
 /**
  * eel_gdk_rectangle_contains_rectangle:
  * @outer: Rectangle possibly containing another rectangle.
@@ -90,29 +53,6 @@ eel_gdk_rectangle_contains_rectangle (GdkRectangle outer, GdkRectangle inner)
 		&& outer.y <= inner.y && outer.y + outer.height >= inner.y + inner.height;
 }
 
-/**
- * eel_rectangle_inset:
- * @rectangle: Rectangle we are insetting.
- * @x: Horizontal ammount to inset by.
- * @y: Vertical ammount to inset by.
- *
- * Inset a rectangle by a given horizontal and vertical ammount.
- * Pass in negative inset values to grow the rectangle, positive to
- * shrink it.
- */
-void
-eel_rectangle_inset (GdkRectangle *rectangle, 
-		     int x, 
-		     int y)
-{
-	g_return_if_fail (rectangle != NULL);
-
-	rectangle->x += x;
-	rectangle->width -= 2 * x;
-	rectangle->y += y;
-	rectangle->height -= 2 * y;
-}
-
 /**
  * eel_interpolate_color:
  * @ratio: Place on line between colors to interpolate.
@@ -611,7 +551,7 @@ eel_stipple_bitmap_for_screen (GdkScreen *screen)
  * This method is not multiscreen safe. Do not use it.
  */
 GdkBitmap *
-eel_stipple_bitmap ()
+eel_stipple_bitmap (void)
 {
 	return eel_stipple_bitmap_for_screen (gdk_screen_get_default ());
 }
