@@ -1,9 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 
 #include <eel/eel-background.h>
-#include <libgnomevfs/gnome-vfs-init.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <gtk/gtkctree.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtkwidget.h>
@@ -14,18 +11,18 @@
 int
 main  (int argc, char *argv[])
 {
-	GtkWidget *window, *ctree;
+	GtkWidget *window;
 	EelBackground *background;
 	char *image_uri;
+#if 0
 	char *titles[] = { "test 1", "test 2", "test 3"};
+#endif
 
 	gtk_init (&argc, &argv);
 
-	gnome_vfs_init ();
-
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	ctree = gtk_ctree_new_with_titles (3, 2, titles);
 #if 0
+	ctree = gtk_ctree_new_with_titles (3, 2, titles);
 	gtk_container_add (GTK_CONTAINER (window), ctree);
 #endif
 	g_signal_connect (window, "destroy",
@@ -36,7 +33,7 @@ main  (int argc, char *argv[])
 	eel_background_set_color (background,
 				  "red-blue:h");
 
-	image_uri = gnome_vfs_get_uri_from_local_path (PATTERNS_DIR "/50s.png");
+	image_uri = g_filename_to_uri (PATTERNS_DIR "/50s.png", NULL, NULL);
 
 #if 1
 	eel_background_set_image_uri (background, image_uri);
